@@ -1,7 +1,7 @@
 package Promises::Deferred::Mojo;
-our $AUTHORITY = 'cpan:STEVAN';
+our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: An implementation of Promises in Perl
-$Promises::Deferred::Mojo::VERSION = '0.96';
+$Promises::Deferred::Mojo::VERSION = '0.97';
 use strict;
 use warnings;
 
@@ -18,6 +18,14 @@ sub _notify_backend {
     });
 }
 
+sub _timeout {
+    my ( $self, $timeout, $callback ) = @_;
+
+    my $id = Mojo::IOLoop->timer( $timeout => $callback );
+    
+    return sub { Mojo::IOLoop->remove($id) };
+}
+
 1;
 
 __END__
@@ -30,7 +38,7 @@ Promises::Deferred::Mojo - An implementation of Promises in Perl
 
 =head1 VERSION
 
-version 0.96
+version 0.97
 
 =head1 SYNOPSIS
 
@@ -67,7 +75,7 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Infinity Interactive, Inc..
+This software is copyright (c) 2017, 2014, 2012 by Infinity Interactive, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
